<?php 
add_action( 'admin_init', 'tg_metabox_add_google_locator' );
add_action( 'admin_head-post.php', 'tg_metabox_locator_print_scripts' );
add_action( 'admin_head-post-new.php', 'tg_metabox_locator_print_scripts' );
add_action( 'save_post', 'tg_metabox_update_locator', 10, 2 );

/**
 * Add custom Meta Box to Posts post type
*/
if ( ! function_exists( 'tg_metabox_add_google_locator' ) ) : 

function tg_metabox_add_google_locator()
{
	add_meta_box(
	'post_locators',
	'Google Locator',
	'tg_metabox_update_google_locator',
	'item',// here you can set post type name
	'normal',
	'core');
}

endif;

/**
 * Print the Meta Box content
 */

if ( ! function_exists( 'tg_metabox_update_google_locator' ) ) :  
function tg_metabox_update_google_locator()
{
	global $post;
	$locators = get_post_meta( $post->ID, 'locators', true );

	// Use nonce for verification
    echo '<input type="hidden" name="locators_meta_box_nonce" value="', wp_create_nonce(basename(__FILE__)), '" />';
	?>
    <div id="dynamic_form">
      <div id="field_wrap">
        <?php 
        if ( isset( $locators['address'] ) ) 
        {
        ?>
        <div class="field_row">
            <div class="form_field">
              <label><?php esc_html_e('Address','weddlist'); ?></label>
              <input class="meta_image_url" type="text" id='gmaps-input-address' name="locators[address]" value="<?php echo esc_attr($locators['address']); ?>" />
            </div>
        <div class="clear"></div>
       </div>      
		<div id="gmaps-canvas"></div>
        <?php esc_html_e('Latitude','weddlist'); ?>:  <input type="text"  id="gmaps-output-latitude" name="locators[latitude]" value="<?php echo esc_attr($locators['latitude']); ?>" /> 
        <?php esc_html_e('Longitude','weddlist'); ?>:  <input type="text"  id="gmaps-output-longitude" name="locators[longitude]" value="<?php echo esc_attr($locators['longitude']); ?>" />
	    <div id="gmaps-error"></div>
        <?php
        }
        else
        { 
		?>
		<div class="field_row">
            <div class="form_field">
              <label>Address</label>
              <input class="meta_image_url" value="" type="text" id='gmaps-input-address' name="locators[address]" />
            </div>
			<div class="clear"></div>
		</div>
		<div id="gmaps-canvas"></div>
        Latitude:  <input type="text"  id="gmaps-output-latitude" name="locators[latitude]"  /> 
        Longitude:  <input type="text"  id="gmaps-output-longitude" name="locators[longitude]" />
	    <div id="gmaps-error"></div>        
		<?php
        }
        ?>

    </div>
    </div>
	<?php
}
endif;

/**
 * Print styles and scripts
 */
if ( ! function_exists( 'tg_metabox_locator_print_scripts' ) ) : 
 
function tg_metabox_locator_print_scripts()
{
	// Check for correct post_type
    global $post;
    if( 'item' != $post->post_type )// here you can set post type name
        return;

	$locators = get_post_meta( $post->ID, 'locators', true );
    ?>
    <script language="javascript">
    <?php 
    if ( isset( $locators['longitude'] ) && $locators['longitude']!="" ) 
    {?>
    var center_lati=<?php echo esc_attr($locators['latitude']);?>;
    var center_long=<?php echo esc_attr($locators['longitude']);?>;
    var center_zoom=11;
    <?php }else{?>
    var center_lati=<?php echo weddlist_maps_center_point_latitude(); ?>;
    var center_long=<?php echo weddlist_maps_center_point_longitude(); ?>;
    var center_zoom=5;    
    <?php } 

    if(function_exists('tg_option')){
    ?>
    var marker_icon='<?php echo esc_url(tg_option('default_marker',false, 'url'));?>';
    <?php } else {?>
    var marker_icon='<?php echo esc_url(get_template_directory_uri().'/assets/images/marker.png');?>';
    <?php } ?>  
    </script>      
	<?php
	wp_enqueue_style( 'google-marker',  plugin_dir_url( __FILE__ )  .'css/google-marker.css');	
	
	wp_enqueue_style( 'google-ui-jquery',  plugin_dir_url( __FILE__ )  .'css/jquery-ui-1.8.16.custom.css');	
	
  wp_enqueue_script('jquery-ui');
  wp_enqueue_script('jquery-ui-draggable');
  wp_enqueue_script('jquery-ui-autocomplete');

	wp_enqueue_script( 'google-locator',  plugin_dir_url( __FILE__ ) .'js/google-locator.js', array('jquery'), 541, true );		
	
	if(function_exists('tg_option')){
		wp_enqueue_script( 'google-map', 'https://maps.google.com/maps/api/js?key='.tg_option('google_map_key').'', array(), null, true );
	}
}

endif;
/**
 * Save post action, process fields
 */ 
if ( ! function_exists( 'tg_metabox_update_locator' ) ) :  
  
function tg_metabox_update_locator( $post_id, $post_object ) 
{
    // Doing revision, exit earlier **can be removed**
    if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE )  
        return;
 
    // Doing revision, exit earlier
    if ( 'revision' == $post_object->post_type )
        return;

    // Verify authenticity

    if ( !isset( $_POST['locators_meta_box_nonce'] ) || !wp_verify_nonce($_POST['locators_meta_box_nonce'] , basename(__FILE__))) {
       return;
    }

   // Correct post type
    if ( 'item' != $_POST['post_type'] ) // here you can set post type name
        return;

    if ( $_POST['locators'] ) 
    {
      // Build array for saving post meta
      $service_data = array();

		//if ($_POST['locators']['address'] != '') 
		//{
			$service_data['address'] 	= $_POST['locators']['address'];
			$service_data['latitude'] 	= $_POST['locators']['latitude'];
			$service_data['longitude'] 	= $_POST['locators']['longitude'];
		//}
        if ( $service_data ) 
        {
          update_post_meta( $post_id, 'locators', $service_data );
          if(isset($service_data['address']))
          {
            update_post_meta( $post_id, 'map_address', $service_data['address'] );
          }
          if(isset($service_data['latitude']))
          {
            update_post_meta( $post_id, 'map_latitude', $service_data['latitude'] );
          }
          if(isset($service_data['longitude']))
          {
            update_post_meta( $post_id, 'map_longitude', $service_data['longitude'] );
          }

        }
        else{
          delete_post_meta( $post_id, 'locators' );
        }       
           
   } 
   // Nothing received, all fields are empty, delete option
   else 
   {
        delete_post_meta( $post_id, 'locators' );
    }
}
endif;
?>