<?php
namespace Elementor;

class Weddlist_Elementor_Location extends Widget_Base {

	public function get_name() {
		return 'location';
	}

	public function get_title() {
		return 'Location';   // title to show on 
	}

	public function get_icon() {
		return 'eicon-post';    //   eicon-posts-ticker-> eicon ow asche icon to show on elelmentor
	}

	public function get_categories() {
		return [ 'weddlist-elements' ];    // category of the widget
	}


	protected function register_controls() {
		
		//start of a control box
		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Location Content', 'weddlist-elementor' ),   //section name for controler view
			]
		);

        $this->add_control(
            'location_image',
            [
                'label' => __( 'Image', 'weddlist-elementor' ),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                        'url' => Utils::get_placeholder_image_src(),
                ],
                'title' => __( 'Select Location Image', 'weddlist-elementor' ),
            ]
        );   

		$this->add_control(
			'location_title',
			[
				'label' => esc_html__( 'Title', 'weddlist-elementor' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
			]
		);
		
		$this->add_control(
			'location_counter_text',
			[
				'label' => esc_html__( 'Counter Text', 'weddlist-elementor' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
                'placeholder' => esc_html__( 'Enter Counter Text', 'weddlist-elementor' ),
			]
		);
		

		$this->add_control(
			'location_id',
			[
				'label' => esc_html__( 'Select Location', 'weddlist-elementor' ),
				'type' => Controls_Manager::SELECT,
				'label_block' => true,
                'options' =>  weddlist_elementor_get_location_options(),
			]
		);

		$this->end_controls_section();


        // Style tab section
        $this->start_controls_section(
            'section_title_area_style',
            [
                'label' => __( 'Section style', 'weddlist-elementor' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

            $this->add_responsive_control(
                'sectionmargin',
                [
                    'label' => __( 'Margin', 'weddlist-elementor' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .section-weddlist-location' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                ]
            );

            $this->add_responsive_control(
                'sectionpadding',
                [
                    'label' => __( 'Padding', 'weddlist-elementor' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .section-weddlist-location' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Background::get_type(),
                [
                    'name' => 'section_title_background',
                    'label' => __( 'Background', 'weddlist-elementor' ),
                    'types' => [ 'classic', 'gradient' ],
                    'selector' => '{{WRAPPER}} .section-weddlist-location',
                ]
            );

            $this->add_group_control(
                Group_Control_Box_Shadow::get_type(),
                [
                    'name' => 'section_title_box_shadow',
                    'label' => __( 'Box Shadow', 'weddlist-elementor' ),
                    'selector' => '{{WRAPPER}} .section-weddlist-location',
                ]
            );

            $this->add_group_control(
                Group_Control_Border::get_type(),
                [
                    'name' => 'section_title_border',
                    'label' => __( 'Border', 'weddlist-elementor' ),
                    'selector' => '{{WRAPPER}} .section-weddlist-location',
                ]
            );

            $this->add_responsive_control(
                'section_border_radius',
                [
                    'label' => __( 'Border Radius', 'weddlist-elementor' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .section-weddlist-location' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                ]
            );


        $this->end_controls_section();


	//End  of a control box

	}
	
	//end of control box 

	protected function render() {				//to show on the fontend 
		$settings = $this->get_settings(); 

        $this->add_render_attribute( 'brands_area_attr', 'class', 'section-weddlist-location' );

		$location_title		     =	$settings['location_title'];
        $location_id             = $settings['location_id'];
        $location_counter_text   = $settings['location_counter_text'];
        
		$html_image   = '';
        $html_title = '';
        $html_details ='';

		?>
		<div <?php echo $this->get_render_attribute_string( 'brands_area_attr' ); ?>>
		<?php


		$html_image.='<div class="city-img">';
		$html_image.= '<img class="img-fluid img-responsive" src="'.$settings['location_image']['url'].'" alt="" />';
		$html_image.= '<div class="overlay-bg"></div></div>';
		

		if(isset($location_title) && !empty($location_title)) { 
            $html_title.='<h4 class="city-dtl-heading">'.$location_title.'</h4>';
        } 

        $get_term=get_term_by('term_id', $location_id, 'location');

        if($get_term)
        {
            $html_start_link    =   '<a  href="'.get_category_link($location_id).'">';
            $html_end_link      =   '</a>';   
            $html_counter_html  =   '<div class="listing_counter">'.$get_term->count.' ';
            $html_counter_html  .=  empty($location_counter_text) ? esc_html__('Listing','weddlist-elementor') : $location_counter_text;
            $html_counter_html  .='</div>';           
        }
        else{
            $html_start_link    =   '';
            $html_end_link      =   '';
            $html_counter_html  =   '';              
        }

	   		printf('%s<div class="location-block">
	   			%s
	   			<div class="city-dtl text-center">
	   			%s
	   			%s
	   			</div>
				</div>
                %s',
                $html_start_link,
				$html_image,
				$html_title,
				$html_counter_html,
                $html_end_link
	 			);

	   	echo '</div>';	
	
	}	

}
\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Weddlist_Elementor_Location() );