<?php
namespace Elementor;

class Weddlist_Elementor_PlanInfo extends Widget_Base {

	public function get_name() {
		return 'planinfo';
	}

	public function get_title() {
		return 'Plan Info';   // title to show on 
	}

	public function get_icon() {
		return 'eicon-favorite';    //   eicon-posts-ticker-> eicon ow asche icon to show on elelmentor
	}

	public function get_categories() {
		return [ 'weddlist-elements' ];    // category of the widget
	}


	protected function register_controls() {
		
		//start of a control box
		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Plan Info Content', 'weddlist-elementor' ),   //section name for controler view
			]
		);

        $this->add_control(
            'planinfo_image',
            [
                'label' => __( 'Image', 'weddlist-elementor' ),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                        'url' => Utils::get_placeholder_image_src(),
                ],
                'title' => __( 'Select Plan Info Image', 'weddlist-elementor' ),
            ]
        );   

		$this->add_control(
			'planinfo_title',
			[
				'label' => esc_html__( 'Title', 'weddlist-elementor' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
			]
		);
		
		$this->add_control(
			'planinfo_details',
			[
				'label' => esc_html__( 'Details', 'weddlist-elementor' ),
				'type' => Controls_Manager::TEXTAREA,
				'label_block' => true,
			]
		);
		

		$this->add_control(
			'planinfo_button_url',
			[
				'label' => esc_html__( 'Button URL', 'weddlist-elementor' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
			]
		);

		$this->end_controls_section();


// Style tab section
        $this->start_controls_section(
            'section_title_area_style',
            [
                'label' => __( 'Section style', 'weddlist-elementor' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

            $this->add_responsive_control(
                'sectionmargin',
                [
                    'label' => __( 'Margin', 'weddlist-elementor' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .section-weddlist-planinfo' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                ]
            );

            $this->add_responsive_control(
                'sectionpadding',
                [
                    'label' => __( 'Padding', 'weddlist-elementor' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .section-weddlist-planinfo' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Background::get_type(),
                [
                    'name' => 'section_title_background',
                    'label' => __( 'Background', 'weddlist-elementor' ),
                    'types' => [ 'classic', 'gradient' ],
                    'selector' => '{{WRAPPER}} .section-weddlist-planinfo',
                ]
            );

            $this->add_group_control(
                Group_Control_Box_Shadow::get_type(),
                [
                    'name' => 'section_title_box_shadow',
                    'label' => __( 'Box Shadow', 'weddlist-elementor' ),
                    'selector' => '{{WRAPPER}} .section-weddlist-planinfo',
                ]
            );

            $this->add_group_control(
                Group_Control_Border::get_type(),
                [
                    'name' => 'section_title_border',
                    'label' => __( 'Border', 'weddlist-elementor' ),
                    'selector' => '{{WRAPPER}} .section-weddlist-planinfo',
                ]
            );

            $this->add_responsive_control(
                'section_border_radius',
                [
                    'label' => __( 'Border Radius', 'weddlist-elementor' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .section-weddlist-planinfo' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                ]
            );

            $this->add_responsive_control(
                'section_alignment',
                [
                    'label' => __( 'Alignment', 'weddlist-elementor' ),
                    'type' => Controls_Manager::CHOOSE,
                    'options' => [
                        'left' => [
                            'title' => __( 'Left', 'weddlist-elementor' ),
                            'icon' => 'fa fa-align-left',
                        ],
                        'center' => [
                            'title' => __( 'Center', 'weddlist-elementor' ),
                            'icon' => 'fa fa-align-center',
                        ],
                        'right' => [
                            'title' => __( 'Right', 'weddlist-elementor' ),
                            'icon' => 'fa fa-align-right',
                        ],
                        'justify' => [
                            'title' => __( 'Justified', 'weddlist-elementor' ),
                            'icon' => 'fa fa-align-justify',
                        ],
                    ],
                    'default' => 'center',
                    'selectors' => [
                        '{{WRAPPER}} .wedding-plan-dtl' => 'text-align: {{VALUE}};',
                    ],
                ]
            );

        $this->end_controls_section();


	//End  of a control box

	}
	
	//end of control box 

	protected function render() {				//to show on the fontend 
		$settings = $this->get_settings(); 

        $this->add_render_attribute( 'brands_area_attr', 'class', 'section-weddlist-planinfo' );

		$planinfo_title			=	$settings['planinfo_title'];
		$planinfo_details		=	$settings['planinfo_details'];
		$planinfo_button_url	=	$settings['planinfo_button_url'];


		$html_image='';
		$html_title='';
		$html_details='';
		?>
		<div <?php echo $this->get_render_attribute_string( 'brands_area_attr' ); ?>>
		<?php

		if(isset($planinfo_button_url) && !empty($planinfo_button_url) && !empty( $settings['planinfo_image']['url'] ))
		{
			$html_image.='<a href="'.$planinfo_button_url.'"><div class="wedding-plan-img">';
			$html_image.= '<img class="img-fluid img-responsive" src="'.$settings['planinfo_image']['url'].'" alt="" />';
			$html_image.= '<div class="overlay-bg"></div></div></a>';
		}
		else if(!empty( $settings['planinfo_image']['url']) ){
			$html_image.='<div class="wedding-plan-img">';
			$html_image.= '<img class="img-fluid img-responsive" src="'.$settings['planinfo_image']['url'].'" alt="" />';
			$html_image.= '<div class="overlay-bg"></div></div>';
		}

		if(isset($planinfo_button_url) && !empty($planinfo_button_url))
		{
			if(isset($planinfo_title) && !empty($planinfo_title)) { $html_title.='<h4 class="heading"><a href="'.$planinfo_button_url.'" class="link">'.$planinfo_title.'</a></h4>';} 
		}
		else
		{
			if(isset($planinfo_title) && !empty($planinfo_title)) { $html_title.='<h4 class="heading">'.$planinfo_title.'</h4>';} 
		}		

		if(isset($planinfo_details) && !empty($planinfo_details)) 
		{ 
			$html_details = '<p class="sub-heading">'.$planinfo_details.'</p>'; 
		}		

	   		printf('<div class="wedding-plan-block">
	   			%s
	   			<div class="wedding-plan-dtl text-center">
	   			%s
	   			%s
	   			</div>
				</div>',
				$html_image,
				$html_title,
				$html_details
	 			);

	   	echo '</div>';	
	
	}	

}
\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Weddlist_Elementor_PlanInfo() );