<?php 
/*
Plugin Name: Weddlist Woocommerce Package
Plugin URI: https://www.thegenius.co/
Description: Weddlist Woocommerce Package plugin used package integration with Woocommerce for weddlist theme.
Author: Udayraj Khatri
Author URI: https://thegenius.co/wp/weddlist/
Version: 1.4.1
Text Domain: weddlist
Domain Path: /languages
*/

/*****************************
*
* Weddlist init load textdomain function
*
*****************************/

add_action( 'init', 'weddlist_woocommerce_package_load_textdomain' );

/**
 * Load plugin textdomain.
 *
 * @since 1.0.0
 */
function weddlist_woocommerce_package_load_textdomain() {
  load_plugin_textdomain( 'weddlist', false, dirname( plugin_basename( __FILE__ ) ) . '/languages' ); 
}


/*****************************
*
* Weddlist WooCommerce Package Options
*
*****************************/

//Downtown Custom Package
function weddlist_woocommerce_register_custom_packages() {
  if ( class_exists( 'WooCommerce' ) )
  {
    class WC_Product_weddlist_woocommerce_register_custom_packages extends WC_Product {
      public $product_type = 'weddlist_item_pkgs';
      public function __construct( $product ) {
        parent::__construct( $product );
      }
    }
  }
}
add_action( 'init', 'weddlist_woocommerce_register_custom_packages', 0 );

function weddlist_woocommerce_item_add_packages_type( $types ){
  // Key should be exactly the same as in the class product_type parameter
  $types[ 'weddlist_item_pkgs' ] = esc_html__( 'Weddlist Packages','weddlist');
  return $types;
}
add_filter( 'product_type_selector', 'weddlist_woocommerce_item_add_packages_type' ,0);


//class for custom product type
function weddlist_woocommerce_item_product_class( $classname, $product_type ) {
    if ( $product_type == 'weddlist_item_pkgs' ) { // notice the checking here.
        $classname = 'WC_Product_weddlist_woocommerce_register_custom_packages';
    }
    return $classname;
}

add_filter( 'woocommerce_product_class', 'weddlist_woocommerce_item_product_class', 10, 2 );

function weddlist_woocommerce_item_hide_attributes_data_panel( $tabs) {
  // Other default values for 'attribute' are; general, inventory, shipping, linked_product, variations, advanced
  $tabs['attribute']['class'][] = 'hide_if_weddlist_item_pkgs';
  $tabs['shipping']['class'][] = 'hide_if_weddlist_item_pkgs';
  $tabs['linked_product']['class'][] = 'hide_if_weddlist_item_pkgs';
  $tabs['advanced']['class'][] = 'hide_if_weddlist_item_pkgs';
  return $tabs;
}
add_filter( 'woocommerce_product_data_tabs', 'weddlist_woocommerce_item_hide_attributes_data_panel' );

/**
 * Show pricing fields for weddlist package product.
 */
function weddlist_woocommerce_item_render_package_custom_js() {

  if ( 'product' != get_post_type() ) :
    return;
  endif;

  ?><script type='text/javascript'>
    jQuery( document ).ready( function() {
      jQuery( '#weddlist_item_pkgs' ).hide();
      jQuery( '.options_group.pricing' ).addClass( 'show_if_weddlist_item_pkgs' ).show();
      jQuery('#product-type').on('change', function()
      {
        if( jQuery(this).val() == 'weddlist_item_pkgs' || jQuery(this).val() == 'subscription')
        {
          jQuery('#weddlist_product_meta').show();
          jQuery("._subscription_sign_up_fee_field").hide();
          jQuery("._subscription_trial_length_field").hide();
        }
        else
        {
          jQuery( '#weddlist_product_meta' ).hide();
          jQuery("._subscription_sign_up_fee_field").show();
          jQuery("._subscription_trial_length_field").show();
        } 
      });
      jQuery('#product-type').trigger( 'change' );
    });

  </script>
<?php
}
add_action( 'admin_footer', 'weddlist_woocommerce_item_render_package_custom_js' );


function weddlist_woocommerce_listing_package_function()
{

  if( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' )) ) || class_exists( 'WooCommerce' ))
  {
    $package_html='';
    $args = array(
    'post_type' => 'product',
    'tax_query' => array(
     'relation' => 'OR',
        array(  
           'taxonomy' => 'product_type',
           'field' => 'slug',
           'terms' => 'weddlist_item_pkgs'
        ),
        array(  
           'taxonomy' => 'product_type',
           'field' => 'slug',
           'terms' => 'subscription'
        ),
      ),  
    'post_status' => 'publish',
    'posts_per_page' => -1,
    'order'=> 'ASC',
    'orderby' => 'date'
    );

    $never_expire = esc_html__('Never Expire','weddlist');
    $yes=esc_html__('Yes','weddlist');
    $no=esc_html__('No','weddlist');
    $package_icon_yes=' package-check-yes';
    $package_icon_no=' package-check-no';

    $packages = new WP_Query( $args );
    if ( $packages->have_posts() )
    {
      $package_html.='<div class="row">';
      while ( $packages->have_posts() )
      {
      $packages->the_post();
      $package_id=get_the_ID();
      $product  = wc_get_product( $package_id);

      $gey_packtype = get_post_meta($package_id, 'weddlist_product_package_type', true );

      $package_recommended = get_post_meta($package_id, 'weddlist_product_package_recommended', true );

      $package_recommended_class='';
      if($package_recommended=='Yes')
      {
        $package_recommended_class=' package-recommended';
      }

      $package_html.='<div class="col-md-4 pricing-table-block no-padding'.esc_attr($package_recommended_class).'">';
      
      if($package_recommended=='Yes')
      {
      $package_html.='<div class="listing-badge">
              <span class="featured">'.esc_html__('Recommended','weddlist').'</span>
            </div>';      
      }
      $package_html.='<div class="pricing-table-block-box">';
      $package_html.='<div class="pricing-table-img-section">';
      $package_html.='<div class="pricing-table-dtl">';


      $package_html.='<h3 class="pricing-table-heading">'.get_the_title().'</h3>';

      $package_html.='<div class="pricing-table-price">'.get_woocommerce_currency_symbol().'&nbsp;'.$product->get_price().'</div>';

      if($product->get_short_description()!="")
      {
        $package_html .= '<div class="p-extra-txt">'.$product->get_short_description().'</div>' ;
      }

      
      $gey_packtype = get_post_meta($package_id, 'weddlist_product_package_type', true );

      $package_expiry = get_post_meta($package_id, 'weddlist_product_package_expiry', true );
      $regular_listing = get_post_meta($package_id, 'weddlist_product_regular_listing', true );
      $featured_listing = get_post_meta($package_id, 'weddlist_product_featured_listing', true );
      $listing_images = get_post_meta($package_id, 'weddlist_product_listing_images', true );

      $package_share = get_post_meta($package_id, 'weddlist_product_package_share', true );
      $package_phone = get_post_meta($package_id, 'weddlist_product_package_phone', true );
      $package_website = get_post_meta($package_id, 'weddlist_product_package_website', true );
      $package_video = get_post_meta($package_id, 'weddlist_product_package_video', true );
      $package_vendorprofile = get_post_meta($package_id, 'weddlist_product_package_vendorprofile', true );
      $featured_vendorprofile = get_post_meta($package_id, 'weddlist_product_package_featured_vendorprofile', true );
      
      $package_html.='</div>';
      $package_html.='</div>';
      $package_html.= '<div class="pricing-table-list">';       
      $package_html.= '<ul>';       


      $package_expiry_line=esc_html__('Package Expiry','weddlist');
      if($package_expiry == '-1')
      {
        $package_html .= '<li class="pricing-feature package-check-yes">'.$package_expiry_line.' : '.$never_expire.'</li>';
      }
      else
      {
        $package_html .= '<li class="pricing-feature package-check-yes">'.$package_expiry_line.' : '.esc_attr($package_expiry).' '.esc_html__('Days','weddlist').'</li>';
      }

      $regular_listing_line=esc_html__('Regular Listing','weddlist');
      if($regular_listing == '-1')
      {
        $package_html .= '<li class="pricing-feature package-check-yes">'.$regular_listing_line.' : '.$never_expire.'</li>';
      }
      else
      {
        $package_html .= '<li class="pricing-feature package-check-yes">'.$regular_listing_line.' : '.esc_attr($regular_listing).'</li>';
      } 
      $featured_listing_line=esc_html__('Featured Listing','weddlist');
      if($featured_listing == '-1')
      {
        $package_html .= '<li class="pricing-feature package-check-yes">'.$featured_listing_line.' : '.$never_expire.'</li>';
      }
      else
      {
        $package_html .= '<li class="pricing-feature package-check-yes">'.$featured_listing_line.' : '.esc_attr($featured_listing).'</li>';
      }

      $listing_images_line=esc_html__('No Of Images Upload','weddlist');
      if($listing_images == '-1')
      {
        $package_html .= '<li class="pricing-feature package-check-yes">'.$listing_images_line.' : '.$listing_images.'</li>';
      }
      else
      {
        $package_html .= '<li class="pricing-feature package-check-yes">'.$listing_images_line.' : '.esc_attr($listing_images).'</li>';
      }                 

      if(!empty($package_video))
      {
        if($package_video == 'Yes')
        {
          $yes_or_no = $yes;
          $icon = $package_icon_yes;
        } else  {
          $yes_or_no = $no;
          $icon = $package_icon_no;
        }
        $package_html .= '<li class="pricing-feature'.esc_attr($icon).'">'.esc_html__('Video Listing','weddlist').' : '.esc_attr($yes_or_no).'</li>';     
      }

      if(!empty($package_share))
      {
        if($package_share == 'Yes')
        {
          $yes_or_no = $yes;
          $icon = $package_icon_yes;
        } else  {
          $yes_or_no = $no;
          $icon = $package_icon_no;
        }
        $package_html .= '<li class="pricing-feature'.esc_attr($icon).'">'.esc_html__('Social Profile','weddlist').' : '.esc_attr($yes_or_no).'</li>';      
      } 

      if(!empty($package_website))
      {
        if($package_website == 'Yes')
        {
          $yes_or_no = $yes;
          $icon = $package_icon_yes;
        } else  {
          $yes_or_no = $no;
          $icon = $package_icon_no;
        }
        $package_html .= '<li class="pricing-feature'.esc_attr($icon).'">'.esc_html__('Website','weddlist').' : '.esc_attr($yes_or_no).'</li>';     
      }     

      if(!empty($package_phone))
      {
        if($package_phone == 'Yes')
        {
          $yes_or_no = $yes;
          $icon = $package_icon_yes;
        } else  {
          $yes_or_no = $no;
          $icon = $package_icon_no;
        }
        $package_html .= '<li class="pricing-feature'.esc_attr($icon).'">'.esc_html__('Phone','weddlist').' : '.esc_attr($yes_or_no).'</li>';     
      }

      if(!empty($package_vendorprofile))
      {
        if($package_vendorprofile == 'Yes')
        {
          $yes_or_no = $yes;
          $icon = $package_icon_yes;
        } else  {
          $yes_or_no = $no;
          $icon = $package_icon_no;
        }
        $package_html .= '<li class="pricing-feature'.esc_attr($icon).'">'.esc_html__('Vendor Profile','weddlist').' : '.esc_attr($yes_or_no).'</li>';      
      } 

      if(!empty($featured_vendorprofile))
      {
        if($featured_vendorprofile == 'Yes')
        {
          $yes_or_no = $yes;
          $icon = $package_icon_yes;
        } else  {
          $yes_or_no = $no;
          $icon = $package_icon_no;
        }
        $package_html .= '<li class="pricing-feature'.esc_attr($icon).'">'.esc_html__('Home Featured Profile','weddlist').' : '.esc_attr($yes_or_no).'</li>';     
      }                             


      $package_html.= '</ul>';        
    
      $current_user=wp_get_current_user();
      $userID          = $current_user->ID;
      $user_package_id=get_user_meta( $userID, 'user_package_id', true ) ;
      $user_payment_expired_date=get_user_meta( $userID, 'user_payment_expired_date', true ) ;
      $user_member_status=get_user_meta( $userID, 'user_member_status', true ) ;



      if(ucfirst($gey_packtype)=='Free' && $user_member_status=='Expired' && $user_payment_expired_date>date('Y-m-d') && $user_package_id==$package_id)
      {
        $package_html .= '<div class="pricing-table-btn"><a href="javascript:void(0)" class="btn btn-default pricing-btn">'.esc_html__('Free Plan Over', 'weddlist').' </a></div>';
      }
      else if($user_package_id==$package_id && $user_payment_expired_date>date('Y-m-d'))
      {
        $package_html .= '<div class="pricing-table-btn"><a href="javascript:void(0)" class="btn btn-default pricing-btn">'.esc_html__('Already Purchased', 'weddlist').' </a></div>';
      }   
      else{
        $package_html .= '<div class="pricing-table-btn"><a href="javascript:void(0)" class="pricing-action weddlist-button-'.$package_id.' weddlist_add_cart btn btn-default pricing-btn" data-product-id="'.$package_id.'" data-product-qty="1"  data-package-type="'.$gey_packtype.'" data-loading-text="<i class=\'fa fa-spinner fa-spin\'></i> '.esc_html__("Processing...", 'dwt-listing').'">'.esc_html__("Choose plan", 'weddlist').' </a></div>';
      }


      $package_html.='</div>';
      $package_html.='</div>';
      $package_html.='</div>';

      }
      $package_html.='</div>';
    }
    //return $products;
  } 
  $package_html.='<input type="hidden" name="weddlist_ajax_url" id="weddlist_ajax_url" 
  value="'.admin_url('admin-ajax.php').'">';

  echo $package_html;
}

add_action('weddlist_woocommerce_listing_package', 'weddlist_woocommerce_listing_package_function');


// After Successfull payment
add_action( 'woocommerce_order_status_completed','weddlist_woocommerce_listing_after_buy_package' );
if ( ! function_exists( 'weddlist_woocommerce_listing_after_buy_package' ) ) {
  function weddlist_woocommerce_listing_after_buy_package( $order_id )
  {
    global $dwt_listing_options;
    $order = new WC_Order( $order_id );
    $user = $order->get_user();
    $userID = $order->get_user_id();
    $items = $order->get_items();
    if(count( $items) > 0 )
    {
      foreach ( $items as $item ){
        $product_id = $item['product_id'];
        $product_type = wc_get_product($product_id);
        if($product_type->get_type() == 'weddlist_item_pkgs' || $product_type->get_type() == 'subscription')
        {
          //store package id
          update_user_meta( $userID, 'user_package_id',$product_id);
          weddlist_woocommerce_listing_store_user_package($userID,$product_id);
        }
      }
    }
  }
}

//For Auto Approval order
add_filter( 'woocommerce_thankyou', 'weddlist_woocommerce_listing_approve_order_auto', 10, 4 );
if ( ! function_exists( 'weddlist_woocommerce_listing_approve_order_auto' ) ) {
  function weddlist_woocommerce_listing_approve_order_auto( $order_id )
  {
     global $dwt_listing_options;
     $order = new WC_Order( $order_id );
     if ( $order->has_status( 'processing' ) || $order->has_status( 'on-hold' ))
     {
      //$order->update_status( 'completed' );
     }
  }
}


  
if(in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' )) ) || class_exists( 'WooCommerce' ))
{
  /*Shop Settings*/
   add_action('pre_get_posts','weddlist_woocommerce_listing_shop_filter_cat');
   function weddlist_woocommerce_listing_shop_filter_cat($query) {
    if (!is_admin() && $query->is_post_type_archive( 'product' ) && $query->is_main_query()) {
       $query->set('tax_query', array(array('taxonomy'   => 'product_type','field' => 'slug','terms' => 'weddlist_item_pkgs','operator' => 'NOT IN'),));   
    }
   }
}


// Ajax handler for add to cart
add_action( 'wp_ajax_weddlist_listing_add_to_cart', 'weddlist_listing_add_to_cart' );
add_action('wp_ajax_nopriv_weddlist_listing_add_to_cart', 'weddlist_listing_add_to_cart');
if ( ! function_exists( 'weddlist_listing_add_to_cart' ) ) {
  function weddlist_listing_add_to_cart()
  {
    global $woocommerce;
    if( get_current_user_id() == "" )
    {
      echo '1';
      die();  
    }
    
    $product_id = $_POST['package_id'];
    $qty  = $_POST['qty'];
    $package_type = $_POST['package_refer'];
    
    //check package type
    if(is_user_logged_in() && $package_type == 'free')
    {

      $current_user   = wp_get_current_user();
      $userID         = $current_user->ID;
      update_user_meta( $userID, 'user_package_id',$product_id);
      update_user_meta( $userID, 'user_is_free_pgk',$product_id);
      update_user_meta( $userID, 'user_member_status', 'Free' ) ; 
      weddlist_woocommerce_listing_store_user_package($userID,$product_id);
      $woocommerce->cart->empty_cart();

      if(function_exists('weddlist_get_vendor_user_dashboard_link'))
      {
        $dashboard_link   =   weddlist_get_vendor_user_dashboard_link();
        $redirect_url     =   $dashboard_link['url']; //redurect page

      }
      else{
        $redirect_url     =  home_url( '/' );
      }
      
      echo ''.$redirect_url;
      die();    
    }
    else
    {
      if( $woocommerce->cart->add_to_cart($product_id, $qty) )
      {
        echo  ''.$woocommerce->cart->get_cart_url();
      }
      else
      {
        echo ''.$woocommerce->cart->get_cart_url();
      }
    }
    die();
  }
}


// Store User Package Details
if( !function_exists('weddlist_woocommerce_listing_store_user_package') )
{
  function weddlist_woocommerce_listing_store_user_package($userID,$product_id) 
  {
     $pkg_exp =  $featured_listing = $regular_listing = ''; 
     $regular_listing = get_post_meta($product_id, 'weddlist_product_regular_listing', true);
     $featured_listing =  get_post_meta($product_id, 'weddlist_product_featured_listing', true );

     $pkg_exp = get_post_meta($product_id, 'weddlist_product_package_expiry', true );
     $gey_packtype = get_post_meta($product_id, 'weddlist_product_package_type', true );

     if(!empty($gey_packtype))
     {
        update_user_meta($userID, 'user_member_status', ucfirst($gey_packtype) );
     }
     //assign simple listings
     if(!empty($regular_listing) && $regular_listing == '-1' )
     {
       update_user_meta($userID, 'user_items', '-1');
     }
     else if( !empty($regular_listing) && is_numeric( $regular_listing ) &&  $regular_listing != 0 )
     {
       update_user_meta( $userID, 'user_items',$regular_listing);
     }
     
     //assign featured listings
     if( !empty($featured_listing) && $featured_listing == '-1' )
     {
       update_user_meta($userID, 'user_featured_listing', '-1');  
     }
     else if( !empty($featured_listing) && is_numeric( $featured_listing ))
     {
      update_user_meta($userID, 'user_featured_listing', $featured_listing );
     }
     
     //assign package days to user
     if( !empty($pkg_exp) && $pkg_exp == '-1' )
     {
      update_user_meta($userID, 'user_payment_expired_date', '-1');
     }
     else
     {
      $expiry_date  = get_user_meta($userID, 'user_payment_expired_date', true );
      $e_date = strtotime( $pkg_exp );  
      $today  = strtotime( date( 'Y-m-d') );
      if( $today > $e_date )
      {
        $new_expiry = date('Y-m-d', strtotime("+$pkg_exp days"));
      }
      else
      {
        $date = date_create( $expiry_date );
        date_add($date,date_interval_create_from_date_string("$pkg_exp days"));
        $new_expiry =  date_format($date,"Y-m-d");
      }
      update_user_meta($userID, 'user_payment_expired_date', $new_expiry );
     }
      //store featured listing expiry days to user  

    $listing_images = get_post_meta($product_id, 'weddlist_product_listing_images', true );

    $package_share = get_post_meta($product_id, 'weddlist_product_package_share', true );
    $package_phone = get_post_meta($product_id, 'weddlist_product_package_phone', true );
    $package_website = get_post_meta($product_id, 'weddlist_product_package_website', true );
    $package_video = get_post_meta($product_id, 'weddlist_product_package_video', true );
    $package_vendorprofile = get_post_meta($product_id, 'weddlist_product_package_vendorprofile', true );
    $featured_vendorprofile = get_post_meta($product_id, 'weddlist_product_package_featured_vendorprofile', true );

    update_user_meta( $userID, 'user_package_images', $listing_images ) ; 
    update_user_meta( $userID, 'user_package_share', $package_share ) ; 
    update_user_meta( $userID, 'user_package_phone', $package_phone ) ; 
    update_user_meta( $userID, 'user_package_website', $package_website ) ; 
    update_user_meta( $userID, 'user_package_video', $package_video ) ; 
    update_user_meta( $userID, 'user_package_vendorprofile', $package_vendorprofile) ;  
    update_user_meta( $userID, 'featured', $featured_vendorprofile) ; 

  }
}
?>