<?php
/**
 * weddlist functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package weddlist
 */

define('KC_LICENSE', 'l483kg4m-jxbv-ju7k-or7h-yhgd-q3jl1ec3fqyi');
update_option('envato_purchase_code_26552218','************************************');

if ( ! function_exists( 'weddlist_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function weddlist_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on weddlist, use a find and replace
		 * to change 'weddlist' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'weddlist', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		add_image_size('weddlist_user_profile', 300, 300, true);
		add_image_size('weddlist_item_thumb', 440, 300, true);
		add_image_size('weddlist_medium_tumb', 700, 450, true);
		add_image_size('weddlist_hero_start', 1000, 600, true);
		add_image_size('weddlist_hero_thumb', 1900, 600, true);
		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'primary' => esc_html__( 'Primary', 'weddlist' ),
			'topbar' => esc_html__( 'Topbar', 'weddlist' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		remove_theme_support( 'widgets-block-editor' );

		/*
		 * Enable support for Post Formats.
		 * See https://developer.wordpress.org/themes/functionality/post-formats/
		 */
		add_theme_support( 'post-formats', array(
			'aside',
			'image',
			'video',
			'quote',
			'link',
			'gallery',
			'audio'
		) );
		
		/*
		 * Enable support for woocommerce.
		 */
		add_theme_support( 'woocommerce' );
		add_theme_support( 'wc-product-gallery-lightbox' );		

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'weddlist_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		// theme implement editor styling
        add_editor_style( '/css/custom-editor-style.css' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );
	}
endif;
add_action( 'after_setup_theme', 'weddlist_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function weddlist_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'weddlist_content_width', 640 );
}
add_action( 'after_setup_theme', 'weddlist_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function weddlist_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'weddlist' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'weddlist' ),
		'before_widget' => '<section id="%1$s" class="sidebar-widget widget-box widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h4 class="blog-sidebar-heading">',
		'after_title'   => '</h4>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Real Wedding Single', 'weddlist' ),
		'id'            => 'sidebar-realwedding',
		'description'   => esc_html__( 'Add widgets here.', 'weddlist' ),
		'before_widget' => '<section id="%1$s" class="sidebar-widget widget-box widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h4 class="blog-sidebar-heading">',
		'after_title'   => '</h4>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Page', 'weddlist' ),
		'id'            => 'weddlist-page',
		'description'   => esc_html__( 'Add widgets here.', 'weddlist' ),
		'before_widget' => '<section id="%1$s" class="sidebar-widget widget-box widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h4 class="blog-sidebar-heading">',
		'after_title'   => '</h4>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'WooCommerce Shop', 'weddlist' ),
		'id'            => 'weddlist-wooCommerce',
		'description'   => esc_html__( 'Add widgets here.', 'weddlist' ),
		'before_widget' => '<section id="%1$s" class="sidebar-widget widget-box widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h4 class="blog-sidebar-heading">',
		'after_title'   => '</h4>',
	) );

	register_sidebar(
		array(
			'name'          => esc_html__( 'Footer 1', 'weddlist' ),
			'id'            => 'footer_1',
			'description'   => esc_html__( 'Add footer widgets here.', 'weddlist' ),
			'before_widget' => '<div id="%1$s" class="%2$s about-widget footer-widget">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="footer-heading">',
			'after_title'   => '</h4>',
		)
	);

	register_sidebar(
		array(
			'name'          => esc_html__( 'Footer 2', 'weddlist' ),
			'id'            => 'footer_2',
			'description'   => esc_html__( 'Add footer widgets here.', 'weddlist' ),
			'before_widget' => '<div id="%1$s" class="%2$s footer-widget">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="footer-heading">',
			'after_title'   => '</h4>',
		)
	);

	register_sidebar(
		array(
			'name'          => esc_html__( 'Footer 3', 'weddlist' ),
			'id'            => 'footer_3',
			'description'   => esc_html__( 'Add footer widgets here.', 'weddlist' ),
			'before_widget' => '<div id="%1$s" class="%2$s footer-widget">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="footer-heading">',
			'after_title'   => '</h4>',
		)
	);

	register_sidebar(
		array(
			'name'          => esc_html__( 'Footer 4', 'weddlist' ),
			'id'            => 'footer_4',
			'description'   => esc_html__( 'Add footer widgets here.', 'weddlist' ),
			'before_widget' => '<div id="%1$s" class="%2$s footer-widget">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="footer-heading">',
			'after_title'   => '</h4>',
		)
	);
}
add_action( 'widgets_init', 'weddlist_widgets_init' );
require get_template_directory() . '/inc/init-files.php';