<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package weddlist
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function weddlist_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	return $classes;
}
add_filter( 'body_class', 'weddlist_body_classes' );

/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 */
function weddlist_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
	}
}
add_action( 'wp_head', 'weddlist_pingback_header' );


/**
 * 	Pagination 
 */
if ( ! function_exists( 'weddlist_pagination' ) ) :
/**
 * Display navigation to next/previous set of posts when applicable.
 *
 * @since Devote 1.0
 *
 * @global WP_Query   $wp_query   WordPress Query object.
 * @global WP_Rewrite $wp_rewrite WordPress Rewrite object.
 */
function weddlist_pagination() {
	global $wp_query, $wp_rewrite;

	// Don't print empty markup if there's only one page.
	if ( $wp_query->max_num_pages < 2 ) {
		return;
	}

	$paged        = get_query_var( 'paged' ) ? intval( get_query_var( 'paged' ) ) : 1;
	$pagenum_link = html_entity_decode( get_pagenum_link() );
	$query_args   = array();
	$url_parts    = explode( '?', $pagenum_link );

	if ( isset( $url_parts[1] ) ) {
		wp_parse_str( $url_parts[1], $query_args );
	}

	$pagenum_link = remove_query_arg( array_keys( $query_args ), $pagenum_link );
	$pagenum_link = trailingslashit( $pagenum_link ) . '%_%';

	$format  = $wp_rewrite->using_index_permalinks() && ! strpos( $pagenum_link, 'index.php' ) ? 'index.php/' : '';
	$format .= $wp_rewrite->using_permalinks() ? user_trailingslashit( $wp_rewrite->pagination_base . '/%#%', 'paged' ) : '?paged=%#%';

	// Set up paginated links.


	if ( $wp_query->max_num_pages>1 ) :
	?>
        <div class="pagination">
            <?php 	echo  paginate_links( array(
						'base'     => $pagenum_link,
						'format'   => $format,
						'total'    => $wp_query->max_num_pages,
						'current'  => $paged,
						'mid_size' => 1,
						'add_args' => array_map( 'urlencode', $query_args ),
						'prev_text' => '<i class="fa fa-angle-left" aria-hidden="true"></i>',
						'next_text' => '<i class="fa fa-angle-right" aria-hidden="true"></i>',
					) );; ?>
        </div>
	<?php
	endif;
}
endif; 

/**
 * Register custom google fonts.
 */

if (! function_exists('weddlist_fonts_url')) :
/**
 * Register Google fonts for Indsutrial theme
 *
 * Create your own weddlist_fonts_url() function to override in a child theme.
 *
 * @since Weddlist Theme 1.0
 *
 * @return string Google fonts URL for the theme.
 */
    function weddlist_fonts_url()
    {
        $fonts_url = '';
        $fonts     = array();
        $subsets   = 'latin,latin-ext';

        /* translators: If there are characters in your language that are not supported by Poppins, translate this to 'off'. Do not translate into your own language. */
        if ('off' !== _x('on', 'Lora font: on or off', 'weddlist')) {
            $fonts[] = 'Lora:400,400i,700,700i';
        }

        if ($fonts) {
            $fonts_url = add_query_arg(array(
            'family' => urlencode(implode('|', $fonts)),
            'subset' => urlencode($subsets),
            ), 'https://fonts.googleapis.com/css');
        }

        return $fonts_url;
    }
endif;


function weddlist_customize_pagination($numpages = '', $pagerange = '', $paged='') {
 
	if (empty($pagerange)) {
		$pagerange = 2;
	}
	 
	/**
	* This first part of our function is a fallback
	* for custom pagination inside a regular loop that
	* uses the global $paged and global $wp_query variables.
	*
	* It's good because we can now override default pagination
	* in our theme, and use this function in default quries
	* and custom queries.
	*/
	global $paged;
	global $wp_rewrite;
		if (empty($paged)) {
			$paged = 1;
		}
	if ($numpages == '') {
		global $wp_query;
		 
		$numpages = $wp_query->max_num_pages;
		if(!$numpages) {
		$numpages = 1;
		}
	}
	 
	/**
	* We construct the pagination arguments to enter into our paginate_links
	* function.
	*/
	 
	 
	$pagination_args = array(
	#'base'            => get_pagenum_link(1) . '%_%',
	'base'            => @add_query_arg('paged','%#%'),
	'format'          => 'page/%#%',
	'total'           => $numpages,
	'current'         => $paged,
	'show_all'        => False,
	'end_size'        => 1,
	'mid_size'        => $pagerange,
	'prev_next'       => true,
	'prev_text'       => '&laquo;',
	'next_text'       => '&raquo;',
	'type'            => 'plain',
	'add_args'        => false,
	'add_fragment'    => ''
	);
	 
	$paginate_links = paginate_links($pagination_args);
	 
	if ($paginate_links) {
		echo "<nav class='pagination'>".$paginate_links."</nav>";
	}
 
}

/**
 * 	Related Post.
 */
if ( ! function_exists( 'weddlist_related_post' ) ) :
 
function weddlist_related_post() {

	global $post;
	$original_post ="";
	$categories = get_the_category($post->ID);
	
	if ($categories) {

			$category_ids = array();		
			foreach($categories as $individual_category) $category_ids[] = $individual_category->term_id;		
				$args=array(
					'category__in' => $category_ids,
					'post__not_in' => array($post->ID),
					'posts_per_page'=> 3, // Number of related posts that will be shown.
					'ignore_sticky_posts'=>1
				);				
				$related_post_query = new wp_query( $args );
				

				if( $related_post_query->have_posts() ) {	

				echo '<div class="blog-related-post"><h3 class="blog-main-hedaing">';
				esc_html_e('Related Post','weddlist');
				echo '</h3> <div class="row">';	
				
					while( $related_post_query->have_posts() ) {
						$related_post_query->the_post(); 
						if ( has_post_thumbnail() ) {

						echo '<div class="col-md-4 col-sm-6">';
						
						echo '<div class="related-post">';
						
							echo '<div class="blog-related-img">';
							echo '<a href="'.get_permalink($related_post_query->id).'">';
							the_post_thumbnail('medium');
							echo '</a>';
							echo '</div>';								
						?>
                            <div class="related-dtl">
	                            <h6 class="related-dtl-heading"><a href="<?php the_permalink()?>" class="related-dtl-heading" ><?php the_title(); ?></a></h6>  
                            </div> 
                        </div>
                        </div>
						<?php
						}
				} // if
				echo '</div></div>';
			} // foreach
	} // if			
	$post = $original_post;
	wp_reset_postdata();
}

endif; 



// single post pre next

if ( ! function_exists( 'weddlist_single_post_pre_next' ) ) :

	function weddlist_single_post_pre_next() {


	 $p = get_adjacent_post(false, '', true); 
	 $n = get_adjacent_post(false, '', false);
	 if(!empty($p) || !empty($n)){
		?>
			<div class="blog-next-pre">
				<div class="row">
					<div class="blog-next-pre-left">
						<div class="col-xs-6 next-post">
						<!-- previous post title with link -->
						<?php if ( ! empty( $p ) ) { ?>
							<h4 class="prev-link linked"><?php previous_post_link( '%link', '<i class="fa fa-long-arrow-left"></i> %title' ); ?></h4>
						<?php } ?>
						</div>
						<div class="col-xs-6 prev-post pull-right">
						<!--  next post title with link -->
						<?php if ( ! empty( $n ) ) { ?>
							<h4 class="next-link linked"><?php next_post_link( '%link', '%title <i class="fa fa-long-arrow-right"></i>' ); ?></h4>
						<?php } ?>
						</div>
					</div>
				</div>
			</div>
		<?php
		
	 }		
		
	}

endif;


if ( ! function_exists( 'weddlist_shape_comment' ) ) :
/**
 * Template for comments and pingbacks.
 *
 * Used as a callback by wp_list_comments() for displaying the comments.
 *
 * @since Shape 1.0
 */
function weddlist_shape_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	extract($args, EXTR_SKIP);

	if ( 'div' == $args['style'] ) {
		$tag = 'div';
		$add_below = 'comment';
	} else {
		$tag = 'li';
		$add_below = 'div-comment';
	}
?>
	<<?php echo esc_attr($tag);?> <?php comment_class( empty( $args['has_children'] ) ? '' : 'parent' ) ?> id="comment-<?php comment_ID() ?>">
	<?php if ( 'div' == $args['style'] ) : ?>
	<div id="div-comment-<?php comment_ID() ?>" class="comment-body review-list">
	<?php endif; ?>
	<div class="row"><!-- row block start-->    
		<?php if (0 != $args['avatar_size']) {?>
        <div class="col-md-2 col-sm-2 hidden-xs avatar-user">      			
            <div class="user-pic">
                <?php echo get_avatar($comment, $args['avatar_size'] ); ?>
            </div>
        </div>
		<?php } ?>       
        <div class="col-md-10 col-sm-10">
            <div class="panel panel-default arrow left">
                 <div class="panel-body">
                 	<div class="text-left">
                    <h6 class="media-heading"><?php 
                        printf(__('%s', 'weddlist'), sprintf('%s', get_comment_author_link())); ?>
                    </h6>
                    <div class="date">
					<i class="fa fa-clock-o"></i> <?php comment_time('d F, Y');	?>
                        <?php echo human_time_diff( get_comment_time('U'), current_time('timestamp') ) . ' ago'; ?>
                        <?php edit_comment_link( esc_html__( '(Edit)', 'weddlist' ), ' ' ); ?> 
                    </div> <!-- meta -->
                    </div>
                    <div class="comment-box">
                    <?php if ( $comment->comment_approved == '0' ) : ?>
                        <em><?php esc_html_e( 'Your comment is awaiting moderation.', 'weddlist' ); ?></em>
                        <br />
                    <?php endif; ?>
                    <?php comment_text(); ?>
                    </div>										
                    <?php comment_reply_link(array_merge($args, array(
								'add_below' => 'div-comment',
								'depth'     => $depth,
								'max_depth' => $args['max_depth'],
								'before'    => '<div class="reply">',
								'after'     => '</div>'				
							)));
					
					?>
                 </div><!-- panel-body -->
            </div>
        </div>
    </div><!-- row block end--> 
	<?php if ( 'div' == $args['style'] ) : ?>
	</div>
	<?php endif; 
	
}
endif; // ends check for weddlist_shape_comment()