<?php
/**
 * Template part for displaying posts
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package weddlist
 */

$post_format = get_post_format();
if ($post_format === false) {
	$post_format = 'image';
}
$data = '';

switch ($post_format) {
	case 'standard':
		$style = 0;
		$data = '';
	break;
	case 'image':
		if (wp_get_attachment_url(get_post_thumbnail_id($post->ID))) {
			$thumbnail_url = wp_get_attachment_url(get_post_thumbnail_id($post->ID));
			$data .= '<a href="'.get_permalink().'"><img class="img-responsive" src="' . esc_url($thumbnail_url). '"/></a>';
		}
	break;
	case 'gallery':
		$values = get_post_custom();
		if(isset($values['product_gallery'])) {
			// The json decode and base64 decode return an array of image ids
			$ids = json_decode($values['product_gallery'][0]);								
		}
		else {
			$ids = array();								
		}												
		if (get_post_meta(get_the_ID(), 'product_gallery', true)) {
			$st_gallery_blog = get_post_meta(get_the_ID(), 'product_gallery', true);
		}															
		$data .= '<div class="owl-gallery-slide owl-carousel mb30">';  // owl-corsol
		foreach ($ids as $item) {
			$thumbnail_url = wp_get_attachment_url($item);
			$data .= '<div class="item post-img">';
			$data .= '<img src="'.esc_url($thumbnail_url).'" class="img-responsive" />';
			$data .= '</div>';
		}
		$data .= '</div>';							
	break;
	case 'video':			    	
		if (get_post_meta(get_the_ID(), 'show_video', true)) {
			$media_url = get_post_meta(get_the_ID(), 'show_video', true);			            
			$data .= '<div class="videoWrapper">';
			$data .= weddlist_video_embed(wp_oembed_get( $media_url ));
			$data .= '</div>';
		}
	break;
	case 'audio':
		if (get_post_meta(get_the_ID(), 'show_audio', true)) {
			$media_url = get_post_meta(get_the_ID(), 'show_audio', true);
			$data .= '<div class="videoWrapper">';
			$data .= '<div class="audio">'. weddlist_video_embed(wp_oembed_get($media_url )) .'</div>';
			$data .= '</div>';
		}
	break;
	default:
		if (wp_get_attachment_url(get_post_thumbnail_id($post->ID))) {
			$thumbnail_url = wp_get_attachment_url(get_post_thumbnail_id($post->ID));
			$data .= '<a href="'.get_permalink().'"><img class="img-responsive" src="' . $thumbnail_url . '"/></a>';
		}
	break;
}
?>
<div class="col-md-4">
	<div class="blog-block">
		<div  id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
		<?php 
	    if(!empty($data))
	    {
			echo '<div class="blog-img">';	
			echo wp_kses_post( $data );		
			echo '</div>';		
	    }
	    ?>
	        <div class="blog-dtl">
	            <?php
	        
	            if ( is_singular() ) :
	                the_title( '<h3 class="blog-heading">', '</h3>' );
	            else :
	                the_title( '<h3 class="blog-heading"><a href="' . esc_url( get_permalink() ) . '" rel="bookmark">', '</a></h3>' );
	            endif;
	            ?>
	              <ul class="meta-tags">
	                <?php weddlist_posted_on(); ?>
	                <li><?php comments_popup_link(
	                    __('No comments', 'weddlist'),
	                    __('1 comment', 'weddlist'),
	                    __('% Comments', 'weddlist'),
	                    'post-comment',
	                    __('Comment Disabled', 'weddlist')
	                ); ?>
	                </li>
	              </ul>	        
	        <a href="<?php the_permalink();?>" class="btn btn-pink"><?php esc_html_e('Read More', 'weddlist'); ?></a>
	        </div>
		</div>
	</div>
</div>